@@ -17,7 +17,8 @@ import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
-def crawl(splash_url: str, url: str, *, cookies: Optional[List[Dict[Any, Any]]]=None, referer: Optional[str]=None, proxy: Optional[str]=None, depth: int=1,
+def crawl(splash_url: str, url: str, *, cookies: Optional[List[Dict[Any, Any]]]=None,
+          referer: Optional[str]=None, proxy: Optional[str]=None, depth: int=1,
           user_agent: str='Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
           log_enabled: bool=False, log_level: str='WARNING') -> List[Dict[Any, Any]]:
     '''Send the URL to crawl to splash, returns a list of responses from splash. Each entry from the list corresponds to a single URL loaded by Splash.'''
@@ -25,9 +26,6 @@ def crawl(splash_url: str, url: str, *, cookies: Optional[List[Dict[Any, Any]]]=
     logger = logging.getLogger(__name__)
     logger.setLevel(log_level)
 
-    if cookies is None:
-        cookies = []
-
     def _crawl(queue: 'Queue[Any]', splash_url: str, ua: str, url: str,
                cookies: List[Dict[Any, Any]], referer: str, proxy: str,
                depth: int, log_enabled: bool, log_level: str) -> None:
@@ -37,9 +35,12 @@ def crawl(splash_url: str, url: str, *, cookies: Optional[List[Dict[Any, Any]]]=
         queue.put(res)
 
     q: Queue[Any] = Queue()
+    # NOTE 2021-09-11: scrapy *really* dislikes None parameters, so we must force to empty.
     p = Process(target=_crawl, args=(q, splash_url, user_agent, url,
-                                     cookies, referer, proxy, depth,
-                                     log_enabled, log_level))
+                                     cookies if cookies else [],
+                                     referer if referer else '',
+                                     proxy if proxy else '',
+                                     depth, log_enabled, log_level))
     p.start()
     res = q.get()
     p.join()
